# -*- coding: utf-8 -*-
import os
import grok
import zope.interface
from grok.interfaces import IGrokSecurityView
from hurry import yui
from zope.component import getMultiAdapter
from zope.location.interfaces import ISite
from waeup.interfaces import (IUniversity, IWAeUPObject, IWAeUPXMLExporter,
                              IWAeUPXMLImporter, IFacultyContainer, IFaculty,
                              IDepartment, ICourse, ICertificate,
                              ICertificateCourse,)
from waeup.utils.helpers import getInnerHTMLPart

master_template_path = os.path.join(
    os.path.dirname(__file__), 'viewlets_templates', 'master.pt')

grok.context(zope.interface.Interface)

class Index(grok.View):
    """main structure for all pages"""
    grok.template('master')
    
class Manage(grok.View):
    """Admin view for waeup objects.
    """
    grok.context(IWAeUPObject)
    grok.template('master')

class Add(grok.View):
    """Admin add form wrapper for waeup objects.
    """
    grok.context(IWAeUPObject)
    grok.template('master')

class AddCourse(grok.View):
    """Admin add form wrapper for waeup objects.

    We need different named add views for departments as there are
    different things to add.
    """
    grok.context(IWAeUPObject)
    grok.template('master')

class AddCertificate(grok.View):
    """Admin add form wrapper for waeup objects.
    
    We need different named add views for departments as there are
    different things to add.
    """
    grok.context(IWAeUPObject)
    grok.template('master')

class AddCertificateCourse(grok.View):
    """Admin add form wrapper for waeup objects.
    
    We need different named add views for departments as there are
    different things to add.
    """
    grok.context(IWAeUPObject)
    grok.template('master')

class ExportXML(grok.View):
    """Deliver an XML representation of the context.
    """
    grok.name('export.xml')
    grok.require('waeup.manageUniversity')
    
    def render(self):
        exporter = IWAeUPXMLExporter(self.context)
        xml = exporter.export().read()
        self.response.setHeader(
            'Content-Type', 'text/xml; charset=UTF-8')
        return xml

class ImportXML(grok.View):
    """Replace the context object by an object created from an XML
       representation.

       XXX: This does not work for ISite objects, i.e. for instance
            for complete University objects.
    """
    grok.require('waeup.manageUniversity')
    grok.template('master')

    def update(self, xmlfile=None, CANCEL=None, SUBMIT=None):
        if CANCEL is not None:
            self.redirect(self.url(self.context))
            return
        if not xmlfile:
            return
        importer = IWAeUPXMLImporter(self.context)
        obj = importer.doImport(xmlfile)
        if type(obj) != type(self.context):
            return
        parent = self.context.__parent__
        name = self.context.__name__
        self.context = obj
        if hasattr(parent, name):
            setattr(parent, name, obj)
        else:
            del parent[name]
            parent[name] = obj
            pass
        return

class Head(grok.ViewletManager):
    """additions to HTML head"""
    grok.name('head')

class Title(grok.Viewlet):
    grok.viewletmanager(Head)

class HeadIncludes(grok.Viewlet):
    """Register CSS and JavaScripts.
    """
    grok.viewletmanager(Head)

    def update(self):
        yui.reset_fonts_grids.need()
        yui.sam.need()
        yui.tabview.need()
        yui.layout.need()
        yui.animation.need()
        yui.resize.need()
        

class Header(grok.ViewletManager):
    grok.name('header')

class Logo(grok.Viewlet):
    grok.viewletmanager(Header)
    grok.order(1)

    def getAppTitle(self):
        """Get the `name` attribute of the local site object.

        This is normally the waeup application or IUniversity object.
        If this object has no ``name`` attribute, then we return the
        empty string.
        """
        app = grok.getSite()
        return getattr(app, 'name', u'')

class NavigationBar(grok.Viewlet):
    grok.viewletmanager(Header)
    grok.order(2)
    
    def getSite(self):
        return grok.getSite()

class LeftSidebar(grok.ViewletManager):
    grok.name('left')

class ExportLink(grok.Viewlet):
    grok.viewletmanager(LeftSidebar)
    grok.view(Index)
    grok.order(99)
    grok.require('waeup.manageUniversity')

    def render(self):
        return '<div class="portlet"><a href="export.xml">%s</a></div>' % (
            'Export as XML',)

class ImportLink(grok.Viewlet):
    grok.viewletmanager(LeftSidebar)
    grok.view(Index)
    grok.order(99)
    grok.require('waeup.manageUniversity')

    def render(self):
        if ISite.providedBy(self.context):
            # We cannot simply replace local sites.
            return ''
        return '<div class="portlet"><a href="importxml">%s</a></div>' % (
            'Import from XML',)
    
class MainArea(grok.ViewletManager):
    grok.name('main')

class ImportXMLViewlet(grok.Viewlet):
    grok.viewletmanager(MainArea)
    grok.view(ImportXML)
